==> kubernetes-model-extensions-5.1.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/DeploymentSpecFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.PodTemplateSpec;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder;
import java.lang.Long;
import io.fabric8.kubernetes.api.model.PodTemplateSpecFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;

public interface DeploymentSpecFluent<A extends DeploymentSpecFluent<A>> extends Fluent<A> {


    public Integer getMinReadySeconds();
    public A withMinReadySeconds(Integer minReadySeconds);
    public Boolean hasMinReadySeconds();
    public Boolean isPaused();
    public A withPaused(Boolean paused);
    public Boolean hasPaused();
    public A withNewPaused(String arg1);
    public A withNewPaused(boolean arg1);
    public Integer getProgressDeadlineSeconds();
    public A withProgressDeadlineSeconds(Integer progressDeadlineSeconds);
    public Boolean hasProgressDeadlineSeconds();
    public Integer getReplicas();
    public A withReplicas(Integer replicas);
    public Boolean hasReplicas();
    public Integer getRevisionHistoryLimit();
    public A withRevisionHistoryLimit(Integer revisionHistoryLimit);
    public Boolean hasRevisionHistoryLimit();
    
/**
 * This method has been deprecated, please use method buildRollbackTo instead.
 * @return The buildable object.
 */
@Deprecated public RollbackConfig getRollbackTo();
    public RollbackConfig buildRollbackTo();
    public A withRollbackTo(RollbackConfig rollbackTo);
    public Boolean hasRollbackTo();
    public A withNewRollbackTo(Long revision);
    public DeploymentSpecFluent.RollbackToNested<A> withNewRollbackTo();
    public DeploymentSpecFluent.RollbackToNested<A> withNewRollbackToLike(RollbackConfig item);
    public DeploymentSpecFluent.RollbackToNested<A> editRollbackTo();
    public DeploymentSpecFluent.RollbackToNested<A> editOrNewRollbackTo();
    public DeploymentSpecFluent.RollbackToNested<A> editOrNewRollbackToLike(RollbackConfig item);
    
/**
 * This method has been deprecated, please use method buildSelector instead.
 * @return The buildable object.
 */
@Deprecated public LabelSelector getSelector();
    public LabelSelector buildSelector();
    public A withSelector(LabelSelector selector);
    public Boolean hasSelector();
    public DeploymentSpecFluent.SelectorNested<A> withNewSelector();
    public DeploymentSpecFluent.SelectorNested<A> withNewSelectorLike(LabelSelector item);
    public DeploymentSpecFluent.SelectorNested<A> editSelector();
    public DeploymentSpecFluent.SelectorNested<A> editOrNewSelector();
    public DeploymentSpecFluent.SelectorNested<A> editOrNewSelectorLike(LabelSelector item);
    
/**
 * This method has been deprecated, please use method buildStrategy instead.
 * @return The buildable object.
 */
@Deprecated public DeploymentStrategy getStrategy();
    public DeploymentStrategy buildStrategy();
    public A withStrategy(DeploymentStrategy strategy);
    public Boolean hasStrategy();
    public DeploymentSpecFluent.StrategyNested<A> withNewStrategy();
    public DeploymentSpecFluent.StrategyNested<A> withNewStrategyLike(DeploymentStrategy item);
    public DeploymentSpecFluent.StrategyNested<A> editStrategy();
    public DeploymentSpecFluent.StrategyNested<A> editOrNewStrategy();
    public DeploymentSpecFluent.StrategyNested<A> editOrNewStrategyLike(DeploymentStrategy item);
    
/**
 * This method has been deprecated, please use method buildTemplate instead.
 * @return The buildable object.
 */
@Deprecated public PodTemplateSpec getTemplate();
    public PodTemplateSpec buildTemplate();
    public A withTemplate(PodTemplateSpec template);
    public Boolean hasTemplate();
    public DeploymentSpecFluent.TemplateNested<A> withNewTemplate();
    public DeploymentSpecFluent.TemplateNested<A> withNewTemplateLike(PodTemplateSpec item);
    public DeploymentSpecFluent.TemplateNested<A> editTemplate();
    public DeploymentSpecFluent.TemplateNested<A> editOrNewTemplate();
    public DeploymentSpecFluent.TemplateNested<A> editOrNewTemplateLike(PodTemplateSpec item);
    public interface RollbackToNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RollbackConfigFluent<DeploymentSpecFluent.RollbackToNested<N>> {

            public N and();
            public N endRollbackTo();    }


    public interface SelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LabelSelectorFluent<DeploymentSpecFluent.SelectorNested<N>> {

            public N and();
            public N endSelector();    }


    public interface StrategyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DeploymentStrategyFluent<DeploymentSpecFluent.StrategyNested<N>> {

            public N and();
            public N endStrategy();    }


    public interface TemplateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodTemplateSpecFluent<DeploymentSpecFluent.TemplateNested<N>> {

            public N and();
            public N endTemplate();    }


}

==> kubernetes-model-extensions-5.1.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/DeploymentSpecFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.PodTemplateSpec;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder;
import java.lang.Long;
import io.fabric8.kubernetes.api.model.PodTemplateSpecFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;

public interface DeploymentSpecFluent<A extends DeploymentSpecFluent<A>> extends Fluent<A> {


    public Integer getMinReadySeconds();
    public A withMinReadySeconds(Integer minReadySeconds);
    public Boolean hasMinReadySeconds();
    public A withNewMinReadySeconds(String arg1);
    public A withNewMinReadySeconds(int arg1);
    public Boolean isPaused();
    public A withPaused(Boolean paused);
    public Boolean hasPaused();
    public A withNewPaused(String arg1);
    public A withNewPaused(boolean arg1);
    public Integer getProgressDeadlineSeconds();
    public A withProgressDeadlineSeconds(Integer progressDeadlineSeconds);
    public Boolean hasProgressDeadlineSeconds();
    public A withNewProgressDeadlineSeconds(String arg1);
    public A withNewProgressDeadlineSeconds(int arg1);
    public Integer getReplicas();
    public A withReplicas(Integer replicas);
    public Boolean hasReplicas();
    public A withNewReplicas(String arg1);
    public A withNewReplicas(int arg1);
    public Integer getRevisionHistoryLimit();
    public A withRevisionHistoryLimit(Integer revisionHistoryLimit);
    public Boolean hasRevisionHistoryLimit();
    public A withNewRevisionHistoryLimit(String arg1);
    public A withNewRevisionHistoryLimit(int arg1);
    
/**
 * This method has been deprecated, please use method buildRollbackTo instead.
 * @return The buildable object.
 */
@Deprecated public RollbackConfig getRollbackTo();
    public RollbackConfig buildRollbackTo();
    public A withRollbackTo(RollbackConfig rollbackTo);
    public Boolean hasRollbackTo();
    public A withNewRollbackTo(Long revision);
    public DeploymentSpecFluent.RollbackToNested<A> withNewRollbackTo();
    public DeploymentSpecFluent.RollbackToNested<A> withNewRollbackToLike(RollbackConfig item);
    public DeploymentSpecFluent.RollbackToNested<A> editRollbackTo();
    public DeploymentSpecFluent.RollbackToNested<A> editOrNewRollbackTo();
    public DeploymentSpecFluent.RollbackToNested<A> editOrNewRollbackToLike(RollbackConfig item);
    
/**
 * This method has been deprecated, please use method buildSelector instead.
 * @return The buildable object.
 */
@Deprecated public LabelSelector getSelector();
    public LabelSelector buildSelector();
    public A withSelector(LabelSelector selector);
    public Boolean hasSelector();
    public DeploymentSpecFluent.SelectorNested<A> withNewSelector();
    public DeploymentSpecFluent.SelectorNested<A> withNewSelectorLike(LabelSelector item);
    public DeploymentSpecFluent.SelectorNested<A> editSelector();
    public DeploymentSpecFluent.SelectorNested<A> editOrNewSelector();
    public DeploymentSpecFluent.SelectorNested<A> editOrNewSelectorLike(LabelSelector item);
    
/**
 * This method has been deprecated, please use method buildStrategy instead.
 * @return The buildable object.
 */
@Deprecated public DeploymentStrategy getStrategy();
    public DeploymentStrategy buildStrategy();
    public A withStrategy(DeploymentStrategy strategy);
    public Boolean hasStrategy();
    public DeploymentSpecFluent.StrategyNested<A> withNewStrategy();
    public DeploymentSpecFluent.StrategyNested<A> withNewStrategyLike(DeploymentStrategy item);
    public DeploymentSpecFluent.StrategyNested<A> editStrategy();
    public DeploymentSpecFluent.StrategyNested<A> editOrNewStrategy();
    public DeploymentSpecFluent.StrategyNested<A> editOrNewStrategyLike(DeploymentStrategy item);
    
/**
 * This method has been deprecated, please use method buildTemplate instead.
 * @return The buildable object.
 */
@Deprecated public PodTemplateSpec getTemplate();
    public PodTemplateSpec buildTemplate();
    public A withTemplate(PodTemplateSpec template);
    public Boolean hasTemplate();
    public DeploymentSpecFluent.TemplateNested<A> withNewTemplate();
    public DeploymentSpecFluent.TemplateNested<A> withNewTemplateLike(PodTemplateSpec item);
    public DeploymentSpecFluent.TemplateNested<A> editTemplate();
    public DeploymentSpecFluent.TemplateNested<A> editOrNewTemplate();
    public DeploymentSpecFluent.TemplateNested<A> editOrNewTemplateLike(PodTemplateSpec item);
    public interface RollbackToNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RollbackConfigFluent<DeploymentSpecFluent.RollbackToNested<N>> {

            public N and();
            public N endRollbackTo();    }


    public interface SelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LabelSelectorFluent<DeploymentSpecFluent.SelectorNested<N>> {

            public N and();
            public N endSelector();    }


    public interface StrategyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DeploymentStrategyFluent<DeploymentSpecFluent.StrategyNested<N>> {

            public N and();
            public N endStrategy();    }


    public interface TemplateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodTemplateSpecFluent<DeploymentSpecFluent.TemplateNested<N>> {

            public N and();
            public N endTemplate();    }


}
